/* -------------------------------------------------------
                        ds18b20_single.c

     Sourcecode fuer das Einlesen eines einzelnen
     DS18B20 Temperatursensors

     MCU   :  CH32V003

     one_wire_Anschluss DS18B20 auf PA1 (aenderbar)

     02.04.2025  R. Seelig
   ------------------------------------------------------ */

/*
   DS18B20
  +-------+
  |       |
  |       |
  |       |
  +-------+
   |  |  |
   |  |  |
   |  |  |

   G  D  V
   N  A  c
   D  T  c
*/


#ifndef in_ds18b20_single
  #define in_ds18b20_single

  #include <stdint.h>
  #include "ch32fun.h"
  #include "ch32v003_gpio.h"


  // -----------------------------------------------------------------------
  //   da das Auslesen des Sensors sehr zeitkritisch ist, sollte / duerfen
  //   die Funktionen nicht von einem Interrupt unterbrochen werden. Wird
  //   dieser Schalter auf 1 gesetzt, werden global alle Interrupts vor
  //   ausfuehren der Lesefunktion gesperrt und nach Beendigung der Lese-
  //   wieder freigegeben.
  // -----------------------------------------------------------------------
  #define DS18B20_STOPINTERRUPTONREAD 0

  #define onewire_clr()     { PA1_output_init(); PA1_clr(); }
  #define onewire_set()     PA1_float_init();
  #define onewire_readb()   is_PA1()


  uint8_t ds18b20_reset();
  int16_t ds18b20_gettemp(void);


#endif
