/* ------------------------------------------------
                  ds18b20_thermometer.c

   Einfaches Thermometerprogramm als Demo fuer
   DS18B20 Sensor mit SSD1306 OLED-Display und
   zusaetzlicher Ausgabe auf UART

   MCU   :  CH32V003
   Takt  :

   12.06.2025 by R. Seelig
  -------------------------------------------------- */
/*
   DS18B20
  +-------+
  |       |
  |       |
  |       |
  +-------+
   |  |  |
   |  |  |
   |  |  |

   G  D  V
   N  A  c
   D  T  c
*/


#include <stdlib.h>
#include "ch32fun.h"
#include "ch32v003_gpio.h"

#include "ds18b20_single.h"
#include "uart.h"
#include "oled_i2c.h"
#include "my_printf.h"

#include "ds18b20screen.h"

#define printf       my_printf

#define intervall    1000                 // Intervallzeit zwischen den Messungen
#define baud         115200

enum { lcd_output, uart_output };

uint8_t outstream = 0;

/* --------------------------------------------------------
   putchar

   wird von my-printf / printf aufgerufen und hier muss
   eine Zeichenausgabefunktion angegeben sein, auf das
   printf dann schreibt !
   -------------------------------------------------------- */
void my_putchar(char ch)
{
  if (outstream == 0)
  {
    lcd_putchar(ch);
  }
  else
  {
    uart_putchar(ch);
  }
}

// Pixelposition, ab dem der Temperaturbalken angezeigt wird
// (untere Position)
#define tscale_ofsx     39
#define tscale_ofsy     46

/* ------------------------------------------------------------------------
                                    MAIN
   ------------------------------------------------------------------------ */

int main(void)
{
  uint16_t cnt;
  int      temp;
  int      t2;

  SystemInit();
  lcd_init();
  uart_init(baud);
  outstream= uart_output;
  printf("\n\n\r --------------------------\n\r");
  printf(    "  DS18B20 Temperatursensor ");
  printf("\n\r --------------------------\n\r");
  outstream= lcd_output;

//  ds18b20_reset();

  clrscr();

  setfont(fnt5x7);
  gotoxy(14,1); printf("DS18B20");
  fb_init(79,8);
  fb_clear();

  fb_showbmp(0,0, &bmpsw_image[0], 0);

  fillrect(39,46, 42,20, 1);
  fb_show(0,0);
  setfont(fnt8x8);
  gotoxy(10,4); printf("Temp.");

  printfkomma= 1;
  cnt= 0;

  while(1)
  {
    temp= ds18b20_gettemp();

    /*
        -5 oC =  0 Pixel
       +55 oC = 40 Pixel
       delta theata = 60 k
    */
    t2= ((temp+50)*2) / 30;

    // alte Temperaturbar loeschen
    fillrect(tscale_ofsx, tscale_ofsy, tscale_ofsx+3, tscale_ofsy -40, 0);

    // neue Temperaturbar setzen
    fillrect(tscale_ofsx, tscale_ofsy, tscale_ofsx+3, tscale_ofsy -t2, 1);
    fb_show(0,0);

    gotoxy(10,6); printf("     ");
    gotoxy(10,6); printf("%k%cC",temp, 248);
    outstream= uart_output;
    printf("\n\r Nr. %d:  ",cnt);
    if (cnt < 10000) { uart_putchar(' '); }
    if (cnt < 1000) { uart_putchar(' '); }
    if (cnt < 100) { uart_putchar(' '); }
    if (cnt < 10) { uart_putchar(' '); }
    printf("%k oC",temp);
    outstream= lcd_output;
    delay(intervall);
    cnt++;

  }

}
