/* -----------------------------------------------------
                        oled_i2c_sw.h

    Header: auf I2C-Display reduzierte Version von
    tft_mono, nur fuer SSD1306 - I2C Display


    Hardware  : CH32V003
    IDE       : make - Projekt
    Toolchain : riscv-none-eabi

    12.06.2025   R. Seelig
  ------------------------------------------------------ */


#ifndef in_oled_i2c_h
  #define in_oled_i2c_h

  #include <stdlib.h>

  #include "ch32fun.h"
  #include "ch32v003_gpio.h"


  #define  ssd1306_addr         0x78              //   I2C Adresse des SSD1306 Displaycontrollers

  #define i2c_sda_hi()      PC1_float_init()
  #define i2c_sda_lo()      { PC1_output_init(); PC1_clr(); }
  #define i2c_is_sda()      is_PC1()

  #define i2c_scl_hi()      PC2_float_init()
  #define i2c_scl_lo()      { PC2_output_init(); PC2_clr(); }

/*
  #define short_puls     1           // Einheiten fuer einen langen Taktimpuls
  #define long_puls      1           // Einheiten fuer einen kurzen Taktimpuls
  #define del_wait       1           // Wartezeit fuer garantierten 0 Pegel SCL-Leitung

  #define short_del()     i2c_delay(short_puls)
  #define long_del()      i2c_delay(long_puls)
  #define wait_del()      i2c_delay(del_wait)
*/

  // wenn keine Wartezeiten bei der Taktgenerierung erzeugt werden sollen
  // hier Dummy-Defines, damit auch die Wartefunktion selbst nicht aufgerufen wird

  #define short_del()     {}
  #define long_del()      {}
  #define wait_del()      {}

  /* --------------------------------------------------
       Schriftstile
     -------------------------------------------------- */

  #define font5x7_enable        0                 // 1: Schriftstil verfuegbar, 0: nicht verfuegbar
  #define font8x8_enable        1                 // 1: Schriftstil verfuegbar, 0: nicht verfuegbar

  #define use_full_ascii        1                 // 0: Ascii-Zeichen bis 127 verfuegbar
                                                  // 1: Ascii-Zeichen bis 255 verfuegbar, Codepage 850

  enum font { fnt5x7, fnt8x8 };

  /* --------------------------------------------------
                   Displayeigenschaften
     -------------------------------------------------- */
  #define _xres                 128
  #define _yres                 64


  #define  fb_enable            1                 //   Framebuffer enable
                                                  //   1 = es wird RAM fuer Framebuffer
                                                  //       reserviert und Grafikfunktionen werden eingebunden
                                                  //   0 = kein Displayram und keine Grafikfunktionen

  #define  fb_size              1038              // Framebuffergroesse in Bytes (wenn fb_enable)



  // --------------------------------------------
  //              globale Variable
  // --------------------------------------------

  extern uint8_t bkcolor;
  extern uint8_t invchar;

  extern uint8_t aktxp;                                // Beinhaltet die aktuelle Position des Textcursors in X-Achse
  extern uint8_t aktyp;                                // dto. fuer die Y-Achse

  extern uint8_t fontnr;                               //  0 : 5x7  Font
                                                       //  1 : 8x8  Font

  extern uint8_t fontsizex;
  extern uint8_t textsize;                             // Skalierung der Ausgabeschriftgroesse


  /* ------------------------------------------------
                       Prototypen
     ------------------------------------------------ */

  void gotoxy(uint8_t x, uint8_t y);
  void clrscr(void);
  void lcd_init(void);

  void setfont(uint8_t fnr);
  void lcd_putchar(uint8_t ch);
  void showimage(uint16_t ox, uint16_t oy, const uint8_t* const image, char mode);

  #if (fb_enable == 1)
    // Framebuffer-Funktionen

    void fb_init(uint8_t x, uint8_t y);
    void fb_clear(void);
    void fb_show(uint8_t x, uint8_t y);
    void fb_putpixel(uint8_t x, uint8_t y, uint8_t col);
    void line(int x0, int y0, int x1, int y1, uint8_t col);
    void rectangle(uint8_t x1, uint8_t y1, uint8_t x2, uint8_t y2, uint8_t col);
    void ellipse(int xm, int ym, int a, int b, uint8_t col );
    void circle(int x, int y, int r, uint8_t col );
    void fastxline(uint8_t x1, uint8_t y1, uint8_t x2, uint8_t col);

    void fillrect(int x1, int y1, int x2, int y2, uint8_t col);
    void fillellipse(int xm, int ym, int a, int b, uint8_t col );
    void fillcircle(int x, int y, int r, uint8_t col );
    void fb_putcharxy(int x, int y, uint8_t ch);
    void fb_outtextxy(int x, int y, char *p);
    void fb_showbmp(uint16_t ox, uint16_t oy, const uint8_t* const image, char mode );

  #endif                  // Framebuffer Funktionen


#endif
