/* ------------------------------------------------------------------
                                oled_text.c

     Textausgabe (keine Grafik) auf einem SSD1306 I2C-Display mit
     Software (BitBanging) I2C-Interface

     MCU   :  CH32V003
     Takt  :

     13.06.2025  R. Seelig
   ------------------------------------------------------------------ */

/*
                  CH32V003 A4M6                                        CH32V003F4P6
                  +-----------+                                      +--------------+
        PC1 / sda |1    C   16| PC0                         PD4 / a7 | 1         20 | PD3 / a4
        PC2 / scl |2    H   15| Vdd                   PD5 / a5 / utx | 2    C    19 | PD2 / a3
              PC3 |3    3   14| gnd                   PD6 / a6 / urx | 3    H    18 | PD1 / swio
              PC4 |4    2   13| PA2 / osc0 / a0           nrst / PD7 | 4    3    17 | PC7 / miso
       PC6 / mosi |5    V   12| PA1 / osc1 / a1      PA1 / osc0 / a1 | 5    2    16 | PC6 / mosi
       PC7 / miso |6    0   11| nrst / PD7           PA2 / osc1 / a0 | 6    V    15 | PC5 / sck / scl
       PD1 / swio |7    0   10| PD6 / a6 / urx                   gnd | 7    0    14 | PC4 / a2
         PD4 / a7 |8    3    9| PD5 / a5 / utx                   PD0 | 8    0    13 | PC3
                  +-----------+                                  Vdd | 9    3    12 | PC2 / scl
                                                                 PC0 | 10        11 | PC1 / sda
                                                                     +--------------+
*/

#include <stdint.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>

#include "ch32fun.h"
#include "ch32v003_gpio.h"

#include "oled_i2c_sw.h"
#include "my_printf.h"

#define  printf               my_printf

#define led_init()           PD4_output_init()
#define led_set()            PD4_set()
#define led_clr()            PD4_clr()

#define speed  1000

/* --------------------------------------------------
                      txbox1

     zeichnet einen Textboxrahmen mit einfachem
     Strich (full Ascii muss enabled sein)

     Uebergabe:
        x1,y1   : Koordinate linke obere Ecke
        x2,y2   : Koordinate rechte untere Ecke
   -------------------------------------------------- */
void txbox1(uint8_t x1, uint8_t y1, uint8_t x2, uint8_t y2)
{
  uint8_t x,y;

  gotoxy(x1,y1);
  lcd_putchar(218);
  for (x=0; x< (x2-x1)-1; x++)
  {
    lcd_putchar(196);
  }
  lcd_putchar(191);
  for (y= 1; y< (y2-y1); y++)
  {
    gotoxy(x1,y1+y);
    lcd_putchar(179);
    for (x=0; x< (x2-x1)-1; x++)
    {
      lcd_putchar(' ');
    }
    lcd_putchar(179);
  }
  gotoxy(x1,y2);
  lcd_putchar(192);
  for (x=0; x< (x2-x1)-1; x++)
  {
    lcd_putchar(196);
  }
  lcd_putchar(217);
}

/* --------------------------------------------------
                      txbox2

     zeichnet einen Textboxrahmen mit doppeltem
     Strich (full Ascii muss enabled sein)

     Uebergabe:
        x1,y1   : Koordinate linke obere Ecke
        x2,y2   : Koordinate rechte untere Ecke
   -------------------------------------------------- */
void txbox2(uint8_t x1, uint8_t y1, uint8_t x2, uint8_t y2)
{
  uint8_t x,y;

  gotoxy(x1,y1);
  lcd_putchar(201);
  for (x=0; x< (x2-x1)-1; x++)
  {
    lcd_putchar(205);
  }
  lcd_putchar(187);
  for (y= 1; y< (y2-y1); y++)
  {
    gotoxy(x1,y1+y);
    lcd_putchar(186);
    for (x=0; x< (x2-x1)-1; x++)
    {
      lcd_putchar(' ');
    }
    lcd_putchar(186);
  }
  gotoxy(x1,y2);
  lcd_putchar(200);
  for (x=0; x< (x2-x1)-1; x++)
  {
    lcd_putchar(205);
  }
  lcd_putchar(188);

}


/* --------------------------------------------------------
   my_putchar

   wird von my-printf / printf aufgerufen und hier muss
   eine Zeichenausgabefunktion angegeben sein, auf das
   printf dann schreibt !
   -------------------------------------------------------- */
void my_putchar(char ch)
{
  lcd_putchar(ch);
}

/* -------------------------------------------------------
                          M-A-I-N
   ------------------------------------------------------- */
int main(void)
{
  uint16_t cx;

  SystemInit();
  lcd_init();

  printfkomma= 2;
  setfont(fnt8x8);

  clrscr();

  textsize= 2;
  gotoxy(0,0);
  printf("CH32V003");
  textsize= 0;
  gotoxy(0,2);

  txbox2(0,3,15,7);
  gotoxy(2,5); printf("Z%chler: ", 132);    // 132 = dt. Umlaut A, Codepage 850x
  cx= 0;
  while(1)
  {
    gotoxy(11,5);
    printf("%d", cx);
    delay(1000);
    cx++;
    cx= cx % 1000;
    if (!cx) { gotoxy(11,5); printf("   "); }
  }
}
